//-----------------------------------------------------------------------
//	File:		$RCSfile: AudioTop.v,v $
//	Version:	$Revision: 1.2 $
//	Desc:		AC97 Controller and Volume Controls
//	Author:		Greg Gibeling
//	Copyright:	Copyright 2003 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Change Log
//-----------------------------------------------------------------------
//	$Log: AudioTop.v,v $
//	Revision 1.2  2004/10/04 17:39:48  SYSTEM
//	Fixed black box bugs
//	Fixed solution missing files
//	
//	Revision 1.1  2004/10/04 05:43:52  Administrator
//	Remade into black box form
//	
//	Revision 1.3  2004/08/13 01:52:54  SYSTEM
//	Changed default imute to 1'b1
//	
//	Revision 1.2  2004/08/12 21:57:07  Administrator
//	Tested in Simulation
//	Fully Working
//	
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		AudioTop
//	Desc:		This module ties the AC97Controller and
//			FullVolumeControl modules together and adds
//			button parsing for the volume control buttons.
//	Params:		clockfreq:	Frequency of the system Clock
//					This clock is only used to
//					generate a proper reset signal.
//			pcmwidth:	Bitwidth of each PCM channel,
//					half the width of PCM_DIn and
//					PCM_DOut.  Note that actual AC97
//					samples are ALWAYS 20bits.
//			pcminrate:	Specify the rate in Hz at which
//					Analog->Digital conversions are
//					made and PCM_DOut samples
//					generated.
//			pcmoutrate:	Specify the rate in Hz at which
//					Digital->Analog conversions are
//					made and PCM_DIn samples
//					consumed.
//			The remaining parameters for this module consist of
//			initial 	volume and mute values for the
//			codec.  The range and default values are indicated
//			in parentheses, loudest value on the right, softest
//			on the left.
//			ivol_master:	Initial Master Volume	(31-0, 8)
//			imute_master:	Initial Master Mute	(1-0, 0)
//			ivol_lineout:	Initial Line Out Volume	(31-0, 8)
//			imute_lineout:	Initial Line Out Mute	(1-0, 0)
//			ivol_linein:	Initial Line In Volume	(31-0, 8)
//			imute_linein:	Initial Line In Mute	(1-0, 1)
//			ivol_wave:	Initial Wave Volume	(31-0, 8)
//			imute_wave:	Initial Wave Mute	(1-0, 0)
//			ivol_recordgain:Initial Record Volume	(0-15, 15)
//			imute_recordgain:Initial Record Mute	(1-0, 0)
//			ivol_mic:	Initial Mic Volume	(31-0, 8)
//			imute_mic:	Initial Mic Mute	(1-0, 1)
//			imicgain:	Initial Mic 20db Gain	(0-1, 0)
//			irecordsource:	Initial Record Source	(RS_*)
//	Constants:	RS_Mic:		Record from microphone
//			RS_CD:		Record from CD
//			RS_Video:	Record from Video
//			RS_Aux:		Record from Aux
//			RS_LineIn:	Record from LineIn
//			RS_StereoMix:	Record from StereoMix (output)
//			RS_MonoMix:	Record from MonoMix (output)
//			RS_PhoneIn:	Record from PhoneIn
//-----------------------------------------------------------------------
module	AudioTop(	//-----------------------------------------------
			//	Audio Codec
			//-----------------------------------------------
			AP_SDATA_OUT,	// OUT(1b), AC97 Serial Data Output
			AP_BIT_CLOCK,	// IN(1b), 12.288MHz bit clock
			AP_SDATA_IN,	// IN(1b), AC97 Serial Data Input
			AP_SYNC,	// OUT(1b), AC97 Serial interface sync
			AP_RESET_,	// OUT(1b), Audio Codec Reset
			AP_PC_BEEP,	// OUT(1b), Used to generate beeps
			//-----------------------------------------------

			//-----------------------------------------------
			//	System Inputs
			//-----------------------------------------------
			Reset,
			Clock,
			//-----------------------------------------------

			//-----------------------------------------------
			//	Host PCM Input Interface
			//-----------------------------------------------
			PCM_DIn,
			PCM_InValid,
			PCM_InRequest,
			//-----------------------------------------------

			//-----------------------------------------------
			//	Host PCM Out Interface
			//-----------------------------------------------
			PCM_DOut,
			PCM_OutValid,
			//-----------------------------------------------

			//-----------------------------------------------
			//	Volume Control Buttons
			//-----------------------------------------------
			VCB_Up,
			VCB_Down,
			VCB_Left,
			VCB_Right,
			VCB_Select,
			//-----------------------------------------------

			//-----------------------------------------------
			//	Record Source Select
			//-----------------------------------------------
			RecordSource,
			//-----------------------------------------------

			//-----------------------------------------------
			//	System Outputs
			//-----------------------------------------------
			AudioReset,
			AudioClock
			//-----------------------------------------------
		); // synthesis syn_black_box
	//---------------------------------------------------------------
	//	Audio Codec
	//---------------------------------------------------------------
	output			AP_SDATA_OUT;
	input			AP_BIT_CLOCK;
	input			AP_SDATA_IN;
	output			AP_SYNC;
	output			AP_RESET_;
	output			AP_PC_BEEP;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	System Inptus
	//---------------------------------------------------------------
	input			Clock, Reset;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Host PCM Input Interface
	//---------------------------------------------------------------
	input	[31:0]	PCM_DIn;
	input			PCM_InValid;
	output			PCM_InRequest;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Host PCM Out Interface
	//---------------------------------------------------------------
	output	[31:0]	PCM_DOut;
	output			PCM_OutValid;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Volume Control Buttons
	//---------------------------------------------------------------
	input			VCB_Up, VCB_Down, VCB_Left, VCB_Right;
	input	[2:0]		VCB_Select;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Record Source Select
	//---------------------------------------------------------------
	input	[2:0]		RecordSource;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	System Outputs
	//---------------------------------------------------------------
	output			AudioReset, AudioClock;
	//---------------------------------------------------------------
endmodule
//-----------------------------------------------------------------------