//-----------------------------------------------------------------------
//	File:		$RCSfile: ClockSource.v,v $
//	Version:	$Revision: 1.2 $
//	Desc:		Clock Source for test benches
//	Author:		Greg Gibeling
//	Copyright:	Copyright 2003 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Defines and Constants
//-----------------------------------------------------------------------
`timescale		1 ns/1 ps		// Display things in ns, compute them in ns
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		ClockSource
//	Desc:		This module will use behavioral verilog to
//			generate a properly gated clock source at any
//			frequency you desire.
//	Params:		clockfreq:	Desired output clock frequency
//			syncdisable:	Will cause this generator to wait
//					for a low value on the clock
//					before disabling it when Enable
//					transitions to low.
//-----------------------------------------------------------------------
module ClockSource(Enable, Clock);
	//---------------------------------------------------------------
	//	Parameters
	//---------------------------------------------------------------
	parameter		clockfreq =		27000000,
				syncdisable =		1;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Constants
	//---------------------------------------------------------------
	localparam		delay =			500000000/clockfreq;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	I/O
	//---------------------------------------------------------------
	input			Enable;
	output			Clock;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Reg
	//---------------------------------------------------------------
	reg			Clock;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Initial
	//---------------------------------------------------------------
	initial Clock =					1'b0;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Gated Clock Source
	//---------------------------------------------------------------
	always @ (posedge Enable) begin
		#(delay);
		while (Enable) begin
			Clock =				~Clock;
			#(delay);
		end
		if (Clock && syncdisable) Clock =	1'b0;
	end
	//---------------------------------------------------------------
endmodule
//-----------------------------------------------------------------------