//-----------------------------------------------------------------------
//	File:		$RCSfile: MAC_Top.v,v $
//	Version:	$Revision: 1.2 $
//	Desc:		MAC Top Level Module
//	Author:		Greg Gibeling
//	Copyright:	Copyright 2003 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Change Log
//-----------------------------------------------------------------------
//	$Log: MAC_Top.v,v $
//	Revision 1.2  2004/10/04 17:39:49  SYSTEM
//	Fixed black box bugs
//	Fixed solution missing files
//	
//	Revision 1.1  2004/10/04 05:43:53  Administrator
//	Remade into black box form
//	
//	Revision 1.7  2004/08/19 00:20:55  SYSTEM
//	Changed config constant to conf (naming conflict)
//	Changed parameters to a generate-compatible style
//	Added width parameter on the IORegisters
//	
//	Revision 1.6  2004/08/13 00:12:11  Administrator
//	Synplify doesn't support non-integer parameters
//	Reworked LocalResetGen parameters
//	Now reset time is specified in cycles of the local clock
//	
//	Revision 1.5  2004/08/10 16:42:49  Administrator
//	Reformatted
//	
//	Revision 1.4  2004/07/29 20:44:10  Administrator
//	Renamed and formatted
//	
//	Revision 1.3  2004/07/22 22:10:46  Administrator
//	Added IOB Registers to eliminate clock problems
//	
//	Revision 1.2  2004/07/22 17:43:21  Administrator
//	Updated all MAC files
//	New revision is incompatible with old revision, but much more flexible
//	Started using standard library
//	Added parameters to MAC_Top
//	
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		MAC_Top
//	Desc:		This is the top level module for configuring and
//			interfacing with the LXT975 PHY
//	Params:		address:	The address of this PHY, only
//					useful if there are multiple PHYs
//			clockfreq:	Frequency of the system clock
//			autoena:	Enable ethernet speed auto
//					negotiation.  Notice that the
//					clocks may change frequency!
//			fasteth:	Select 100Tx (only applies when
//					autoena is off)
//			fulldup:	Select full duplex mode (only
//					applies when autoena is off)
//			portmask:	4bit mask to enable specific
//					ports.  4'hF enables all ports.
//			width:		width of the TXDIn and RXDOut
//					busses.
//			resetholdcycles:	Time to hold the PHY_RESET_
//					signall active.
//-----------------------------------------------------------------------
module	MAC_Top(	//-----------------------------------------------
			//	LEDs
			//-----------------------------------------------
			RJ45_TRC_,	// OUT(2b), LEDs on the Top Right
			RJ45_BRC_,	// OUT(2b), LEDs on the Bottom Right
			RJ45_TLC_,	// OUT(2b), LEDs on the Top Left
			RJ45_BLC_,	// OUT(2b), LEDs on the Bottom Left
			PHY_LED0_,	// IN(3b), LEDs for port 0
			PHY_LED1_,	// IN(3b), LEDs for port 1
			PHY_LED2_,	// IN(3b), LEDs for port 2
			PHY_LED3_,	// IN(3b), LEDs for port 3
			//-----------------------------------------------

			//-----------------------------------------------
			//	LED Serial Interface
			//-----------------------------------------------
			// These signals provide a serial readout of the Ethernet
			// chips LED outputs.  The chip will drive the PHY_LEDENA
			// output high and then clock out 24bits of LED status
			// data, driving both PHY_LEDDAT and PHY_LEDCLK
			PHY_LEDCLK,	// IN(1b), Clock
			PHY_LEDDAT,	// IN(1b), Data
			PHY_LEDENA,	// IN(1b), Enable
			//-----------------------------------------------

			//-----------------------------------------------
			//	Miscelaneous
			//-----------------------------------------------
			PHY_ADD,	// OUT(3b), Address set (0 for CalLinx)
			PHY_PWRDN,	// OUT(1b), Powerdown Control
			PHY_RESET_,	// OUT(1b), Active Low Reset
			//-----------------------------------------------

			//-----------------------------------------------
			//	MII Control Interface Lines
			//-----------------------------------------------
			PHY_MDIO,	// INOUT(1b), MII Data Bus
			PHY_MDINT_,	// IN(1b), MII Control Interrupt
			PHY_MDC,	// OUT(1b), MII Clock
			PHY_MDDIS,	// OUT(1b), MII Disable
			//-----------------------------------------------

			//-----------------------------------------------
			//	Hardware Control Interface
			//-----------------------------------------------
			PHY_FDE,	// OUT(1b)
			PHY_AUTOENA,	// OUT(1b)
			PHY_BYPSCR,	// OUT(1b)
			PHY_CFG,	// OUT(3b), Phy Chip config lines
			PHY_TRSTE,	// OUT(4b), Tristate Control[Port]
			//-----------------------------------------------

			//-----------------------------------------------
			//	Ethernet Receive Interface
			//-----------------------------------------------
			PHY_RXD0,	// IN(4b), Receive Data port 0
			PHY_RXD1,	// IN(4b), Receive Data port 1
			PHY_RXD2,	// IN(4b), Receive Data port 2
			PHY_RXD3,	// IN(4b), Receive Data port 3
			PHY_RX_DV,	// IN(4b), Receive Data Valid[Port]
			PHY_RX_ER,	// IN(4b), Receive Error[Port]
	   		PHY_RX_CLK,	// IN(4b), Receive Data Clock[Port]
			//-----------------------------------------------

			//-----------------------------------------------
			//	Ethernet Transmit Interface
			//-----------------------------------------------
	   		PHY_TX_CLK,	// IN(4b), Transmit Data Clock[Port]
			PHY_TX_EN,	// OUT(4b), Transmit Data Clock[Port]
			PHY_TX_ER,	// OUT(4b), Transmit Error[Port]
			PHY_TXD0,	// OUT(4b), Transmit Data port 0
			PHY_TXD1,	// OUT(4b), Transmit Data port 1
			PHY_TXD2,	// OUT(4b), Transmit Data port 2
			PHY_TXD3,	// OUT(4b), Transmit Data port 4
			//-----------------------------------------------

			//-----------------------------------------------
			//	Ethernet Link Status Lines
			//-----------------------------------------------
	   		PHY_COL,	// IN(4b), Collision Detect
  			PHY_CRS,	// IN(4b), Carrier Sense
			//-----------------------------------------------

			//-----------------------------------------------
			//	System Inputs
			//-----------------------------------------------
			Clock,
			Reset,
			//-----------------------------------------------

			//-----------------------------------------------
			//	Transmit Data Interface
			//-----------------------------------------------
			TXReset, TXInRequest,
			TXDIn0, TXDIn1, TXDIn2, TXDIn3,
			TXInValid,
			//-----------------------------------------------

			//-----------------------------------------------
			//	Receive Data Interface
			//-----------------------------------------------
			RXReset, RXOutValid, RXPacketValid, RXPacketInvalid,
			RXDOut0, RXDOut1, RXDOut2, RXDOut3
			//-----------------------------------------------
		); // synthesis syn_black_box
	//---------------------------------------------------------------
	//	LEDs
	//---------------------------------------------------------------
	output	[2:1]		RJ45_TRC_, RJ45_BRC_, RJ45_TLC_, RJ45_BLC_;
	input	[2:0]		PHY_LED0_, PHY_LED1_, PHY_LED2_, PHY_LED3_;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	LED Serial Interface
	//---------------------------------------------------------------
	input 	 		PHY_LEDCLK, PHY_LEDDAT, PHY_LEDENA;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Miscelaneous
	//---------------------------------------------------------------
	output	[4:2]		PHY_ADD;
	output			PHY_PWRDN, PHY_RESET_;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	MII Control Interface Lines
	//---------------------------------------------------------------
	inout			PHY_MDIO;
	input			PHY_MDINT_;
	output			PHY_MDC, PHY_MDDIS;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Hardware Control Interface	
	//---------------------------------------------------------------
	output			PHY_FDE, PHY_AUTOENA, PHY_BYPSCR;
	output	[2:0]		PHY_CFG;
	output	[3:0]		PHY_TRSTE;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Ethernet Receive Interface
	//---------------------------------------------------------------
	input	[3:0]		PHY_RXD0, PHY_RXD1, PHY_RXD2, PHY_RXD3;
	input	[3:0]		PHY_RX_DV, PHY_RX_ER;
	input	[3:0]		PHY_RX_CLK;	/* synthesis syn_noclockbuf=1 */
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Ethernet Transmit Interface
	//---------------------------------------------------------------
	input	[3:0]		PHY_TX_CLK;	/* synthesis syn_noclockbuf=1 */
	output	[3:0]		PHY_TX_EN, PHY_TX_ER;
	output	[3:0]		PHY_TXD0, PHY_TXD1, PHY_TXD2, PHY_TXD3;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Ethernet Link Status Lines
	//---------------------------------------------------------------
	input	[3:0]		PHY_COL, PHY_CRS;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	System Inputs
	//---------------------------------------------------------------
	input			Clock, Reset;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Transmit Data Interface
	//---------------------------------------------------------------
	output	[3:0]		TXReset, TXInRequest;
	input	[31:0]	TXDIn0, TXDIn1, TXDIn2, TXDIn3;
	input	[3:0]		TXInValid;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Receive Data Interface
	//---------------------------------------------------------------
	output	[3:0]		RXReset, RXOutValid, RXPacketValid, RXPacketInvalid;
	output	[31:0]	RXDOut0, RXDOut1, RXDOut2, RXDOut3;
	//---------------------------------------------------------------
endmodule
//-----------------------------------------------------------------------